krun_add_input_device

Function krun_add_input_device 

pub unsafe extern "C" fn krun_add_input_device(
    ctx_id: u32,
    config_backend: *const c_void,
    config_backend_size: usize,
    events_backend: *const c_void,
    events_backend_size: usize,
) -> c_int
Adds an input device with separate config and events objects.

Arguments: “ctx_id” - the configuration context ID “config_backend” - Pointer to a krun_input_config struct “config_backend_size” - sizeof() the krun_input_config struct “events_backend” - Pointer to a krun_input_event_provider struct “events_backend_size” - sizeof() the krun_input_event_provider struct

Returns: Zero on success or a negative error code otherwise.