pub unsafe extern "C" fn krun_set_env(
ctx_id: u32,
envp: *const *const c_char,
) -> i32Expand description
Sets environment variables to be configured in the context of the executable.
Arguments: “ctx_id” - the configuration context ID. “envp” - an array of string pointers to be injected as environment variables into the context of the executable. If NULL, it will auto-generate an array collecting the the variables currently present in the environment.
Returns: Zero on success or a negative error number on failure.