pub unsafe extern "C" fn krun_set_root_disk(
ctx_id: u32,
disk_path: *const c_char,
) -> i32Expand description
DEPRECATED. Use krun_add_disk instead.
Sets the path to the disk image that contains the file-system to be used as root for the microVM. The only supported image format is “raw”.
Arguments: “ctx_id” - the configuration context ID. “disk_path” - a null-terminated string representing the path leading to the disk image that contains the root file-system.
Returns: Zero on success or a negative error number on failure.