krun_set_workdir

Function krun_set_workdir 

pub unsafe extern "C" fn krun_set_workdir(
    ctx_id: u32,
    workdir_path: *const c_char,
) -> i32
Sets the working directory for the executable to be run inside the microVM.

Arguments: “ctx_id” - the configuration context ID. “workdir_path” - the path to the working directory, relative to the root configured with “krun_set_root”.

Returns: Zero on success or a negative error number on failure.