pub unsafe extern "C" fn krun_set_nested_virt(
ctx_id: u32,
enabled: bool,
) -> i32Expand description
Configures the microVM to support Nested Virtualization
Arguments: “ctx_id” - the configuration context ID. “enabled” - true to enable Nested Virtualization in the microVM.
Notes: This feature is only supported on macOS.
Returns: Zero on success or a negative error number on failure. Success doesn’t imply that Nested Virtualization is supported on the system, only that it’s going to be requested when the microVM is created after calling “krun_start_enter”.