pub unsafe extern "C" fn krun_set_root(
ctx_id: u32,
root_path: *const c_char,
) -> i32Expand description
Sets the path to be use as root for the microVM. Not available in libkrun-SEV.
Arguments: “ctx_id” - the configuration context ID. “root_path” - a null-terminated string representing the path to be used as root.
Returns: Zero on success or a negative error number on failure.